@@ -1,16 +1,28 @@
+import logging
 from typing import Any, Callable, Dict
 
 from .common import extract_extension_attributes, extract_typed_props, merge_schema, PropertyMeta
 from ..enumeration import DataType, IntegerFormat, NumberFormat, StringFormat
 from ..errors import ParserError
-from ..specification import Array, Boolean, Integer, Number, Object, Property, PropertyList, Schema, String
+from ..specification import Array, Boolean, Discriminator, Integer, Number, Object, OneOf, Property, Schema, String
 
 SchemaBuilderMethod = Callable[[dict], Schema]
 
 ALL_OF_SCHEMAS_KEY = 'allOf'
 
+logger = logging.getLogger(__name__)
+
 
 def extract_attrs(data: dict, attrs_map: Dict[str, PropertyMeta]) -> Dict[str, Any]:
+    """Extract attributes of schema description with specific type-casting mapping
+
+    Args:
+        data (dict): Source dictionary with schema data
+        attrs_map (Dict[str, PropertyMeta]): Type-casting mapping
+
+    Returns:
+        Dict[str, Any]: Extracted dictionary with typed values
+    """
     base_attrs_map = {
         "type": "type",
         "title": "title",
@@ -36,13 +48,26 @@ def extract_attrs(data: dict, attrs_map: Dict[str, PropertyMeta]) -> Dict[str, A
 
     attrs['extensions'] = extract_extension_attributes(data)
 
+    if attrs['extensions']:
+        logger.debug(f"Extracted custom properties [{attrs['extensions'].keys()}]")
+
     return attrs
 
 
 def merge_all_of_schemas(original_data: dict) -> dict:
+    """Recursive merge schemas with 'allOf' type into single schema dictionary
+
+    Args:
+        original_data (dict): Dictionary with schema description
+
+    Returns:
+        dict: Merged dictionary of schema item
+    """
     if ALL_OF_SCHEMAS_KEY not in original_data.keys():
         return original_data
 
+    logger.debug(f"Merging 'allOf' schemas")
+
     schema_dict: dict = {}
 
     for nested_schema_dict in original_data[ALL_OF_SCHEMAS_KEY]:
@@ -63,22 +88,31 @@ class SchemaFactory:
             DataType.BOOLEAN: self._boolean,
             DataType.ARRAY: self._array,
             DataType.OBJECT: self._object,
+            DataType.ONE_OF: self._one_of,
         }
 
     def create(self, data: dict) -> Schema:
         data = merge_all_of_schemas(data)
 
-        schema_type = data['type']
+        if 'oneOf' in data.keys():
+            data['type'] = DataType.ONE_OF
+
+        try:
+            schema_type = data['type']
+        except KeyError:
+            raise ParserError("Schema does not contain 'type' property")
 
         try:
             data_type = DataType(schema_type)
         except ValueError:
-            raise ParserError(f"Invalid schema type '{schema_type}'")
+            raise ParserError(f"Invalid schema type '{schema_type}'") from None
 
         try:
             builder_func = self._builders[data_type]
         except KeyError:
-            raise ParserError(f"Unsupported schema type: '{schema_type}'")
+            raise ParserError(f"Unsupported schema type: '{schema_type}'") from None
+
+        logger.debug(f"Building schema [type={data_type}]")
 
         return builder_func(data)
 
@@ -131,12 +165,10 @@ class SchemaFactory:
             "items": PropertyMeta(name="items", cast=self.create),
         }
 
-        attrs = extract_attrs(data, attrs_map)
-
-        return Array(**attrs)
+        return Array(**extract_attrs(data, attrs_map))
 
     def _object(self, data: dict) -> Object:
-        def build_properties(object_attrs: dict) -> PropertyList:
+        def build_properties(object_attrs: dict) -> list[Property]:
             return [
                 Property(name, self.create(schema))
                 for name, schema in object_attrs.items()
@@ -149,6 +181,26 @@ class SchemaFactory:
             "properties": PropertyMeta(name="properties", cast=build_properties),
         }
 
-        attrs = extract_attrs(data, attrs_map)
+        return Object(**extract_attrs(data, attrs_map))
 
-        return Object(**attrs)
+    def _one_of(self, data: dict) -> OneOf:
+        def create_inner_schemas(schemas: list) -> list[Schema]:
+            return [self.create(x) for x in schemas]
+
+        def build_discriminator(discriminator_data: dict) -> Discriminator:
+            discriminator = Discriminator(property_name=discriminator_data['propertyName'])
+
+            if 'mapping' in discriminator_data:
+                discriminator.mapping = {
+                    key: self.create(schema) for key, schema
+                    in discriminator_data['mapping'].items()
+                }
+
+            return discriminator
+
+        attrs_map = {
+            "schemas": PropertyMeta(name="oneOf", cast=create_inner_schemas),
+            "discriminator": PropertyMeta(name="discriminator", cast=build_discriminator),
+        }
+
+        return OneOf(**extract_attrs(data, attrs_map))
